==> xpdl-parser-1.0.12-sources.jar: com/plusmpm/parser/xpdlelements/Participant.java <==
/**
 *
 */
package com.plusmpm.parser.xpdlelements;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class Participant
    extends XpdlNode
{
    private static Logger log = Logger.getLogger( Participant.class );

    public Participant( Node el, XpdlNode parentNode )
    {
        super( el, parentNode );
    }

    public String getId()
    {
        return this.parentNode.getId() + "_PARTICIPANT(" + this.id + ")";
    }

    public static List<Participant> findParticipants( Node node, XpdlNode xpdlNode )
    {
        List<Participant> participants = new ArrayList<Participant>();

        NodeList childrenNodes = node.getChildNodes();

        for ( int i = 0; i < childrenNodes.getLength(); i++ )
        {
            Node child = childrenNodes.item( i );
			if ("Participants".equals(child.getLocalName()))
            {
                NodeList participantNodes = child.getChildNodes();

                for ( int j = 0; j < participantNodes.getLength(); j++ )
                {
                    Node participantNode = participantNodes.item( j );
					if ("Participant".equals(participantNode.getLocalName()))
                        participants.add( new Participant( participantNode, xpdlNode ) );
                }
            }
        }
        if ( participants.isEmpty() )
        {
			log.info("Brak ról na poziomie: '" + xpdlNode.getId() + "'");
        }

        return participants;
    }
}

==> xpdl-parser-1.0.13-sources.jar: com/plusmpm/parser/xpdlelements/Participant.java <==
/**
 *
 */
package com.plusmpm.parser.xpdlelements;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class Participant
    extends XpdlNode
{
    private static Logger log = Logger.getLogger( Participant.class );

    public Participant( Node el, XpdlNode parentNode )
    {
        super( el, parentNode );
    }

    public String getId()
    {
        return this.parentNode.getId() + "_PARTICIPANT(" + this.id + ")";
    }

    public static List<Participant> findParticipants( Node node, XpdlNode xpdlNode )
    {
        List<Participant> participants = new ArrayList<Participant>();

        NodeList childrenNodes = node.getChildNodes();

        for ( int i = 0; i < childrenNodes.getLength(); i++ )
        {
            Node child = childrenNodes.item( i );
			if ("Participants".equals(child.getLocalName()))
            {
                NodeList participantNodes = child.getChildNodes();

                for ( int j = 0; j < participantNodes.getLength(); j++ )
                {
                    Node participantNode = participantNodes.item( j );
					if ("Participant".equals(participantNode.getLocalName()))
                        participants.add( new Participant( participantNode, xpdlNode ) );
                }
            }
        }
        if ( participants.isEmpty() )
        {
			log.trace("Brak ról na poziomie: '" + xpdlNode.getId() + "'");
        }

        return participants;
    }
}
